@@ -47,12 +47,12 @@ class ExporterObject(object):
                     try:
                         v = int(v)
                     except ValueError:
-                        print('Warning: Failed to force "{0}" to float, skip...'.format(v))
+                        print('Warning: Failed to force "{0}" to int, skip...'.format(v))
                 if force_float_columns and column in force_float_columns:
                     try:
                         v = float(v)
                     except ValueError:
-                        print('Warning: Failed to force "{0}" to int, skip...'.format(v))
+                        print('Warning: Failed to force "{0}" to float, skip...'.format(v))
 
                 # If field is empty
                 if len(str(v)) == 0:
@@ -428,9 +428,16 @@ class ExporterObject(object):
 
                 # Process Time
                 try:
-                    timestamp_float = float(row[time_column])
-                    timestamp_remove_decimal = int(str(timestamp_float).replace('.', ''))
-                    timestamp_influx = '{:<019d}'.format(timestamp_remove_decimal)
+                    # raise if not posix-time-like
+                    timestamp_str = str(float(row[time_column]))
+                    timestamp_magnitude = len(timestamp_str.split('.')[0])
+                    timestamp_remove_decimal = int(
+                        str(timestamp_str).replace('.', '')
+                    )
+                    # add zeros to convert to nanoseconds
+                    timestamp_influx = (
+                        '{:<0'+str(9+timestamp_magnitude)+'d}'
+                    ).format(timestamp_remove_decimal)
                     timestamp = int(timestamp_influx)
                 except ValueError:
                     try:
